@@ -1,3 +1,4 @@
+import time
 import requests
 import click
 import os
@@ -260,7 +261,7 @@ def upload_bag(rosbag_file_name, source):
 @click.argument('topics_file', type=click.Path(exists=True))
 @click.argument('rosbag_file_name')
 @click.argument('source')
-@click.option('--delete_rosbag', is_flag=True, help='Keep the rosbag file after recording')
+@click.option('--delete_rosbag', is_flag=True, default=False, help='Keep the rosbag file after recording')
 def record_rosbag(topics_file, rosbag_file_name, source, delete_rosbag):
 
     with open(topics_file) as f:
@@ -284,8 +285,21 @@ def record_rosbag(topics_file, rosbag_file_name, source, delete_rosbag):
         process.terminate()
         print("Recording stopped")
 
+        pwd = os.getcwd()
+        path = os.path.join(pwd, rosbag_file_name)
+        print(f"Recording saved at: {path}")
+
+        time.sleep(2)
+
+        # check connection
+        net = "IllinoisNet"
+        while(process.check_output("iwgetid -r", shell=True).decode().strip() != net):
+            print("Not connected to IllinoisNet. Retrying in 1 second")
+            time.sleep(1)
+
         # send rosbag file through api
-        upload_bag(rosbag_file_name, source)
+        print("Uploading rosbag file")
+        upload_bag(path, source)
        
         if delete_rosbag:
             print("Removing rosbag file")
